<?php

namespace forge12\contactform7\CF7Captcha {

    use forge12\contactform7\CF7Captcha\core\log\Log_Item;
    use forge12\contactform7\CF7Captcha\core\log\Log_WordPress;

    if (!defined('ABSPATH')) {
        exit;
    }

    /**
     * Class AvadaValidator
     */
    class AvadaValidator
    {
        public function __construct()
        {
            add_action('fusion_form_before_close', array($this, 'addSpamProtection'), 10, 2);
            add_filter('fusion_form_demo_mode', array($this, 'validateSpamProtection'), 10, 1);
        }

        /**
         * @return string
         */
        private function getPostFieldName()
        {
            $settings = CF7Captcha::getInstance()->getSettings();

            $fieldname = 'f12_captcha';
            if (isset($settings['avada']['protect_avada_fieldname'])) {
                $fieldname = $settings['avada']['protect_avada_fieldname'];
            }
            return $fieldname;
        }

        /**
         * @param array $default
         * @return array
         */
        public function addSpamProtection($default)
        {
            $settings = CF7Captcha::getInstance()->getSettings();
            $fieldname = $this->getPostFieldName();

            ?>
            <input
                    type="hidden"
                    style="visibility:hidden; opacity:1; height:0; width:0; margin:0; padding:0;"
                    name="<?php esc_attr_e($fieldname); ?>"
                    value=""
            />
            <?php
            return $default;
        }

        public function validateSpamProtection($value)
        {
            /**
             * Avada sends the form fields as formdata string.
             */
            if (isset($_POST['formData'])) {
                $formData = ControllerAvada::formDataToArray($_POST['formData']);

                $fieldname = $this->getPostFieldName();

                if ((!isset($formData[$fieldname]) || !empty($formData[$fieldname]))) {

                    /*
                     * Add Log Entries
                     */
                    $Log_Item = new Log_Item(
                        __('Avada Fom - Captcha Validator', 'f12-captcha'),
                        $_POST,
                        'spam',
                        'Captcha failed in AvadaValidator.class.php');
                    Log_WordPress::store($Log_Item);

                    die(wp_json_encode(ControllerAvada::get_results_from_message('error', 'spam')));
                }
            }
            return $value;
        }
    }
}