<?php

namespace forge12\contactform7\CF7Captcha {
    if (!defined('ABSPATH')) {
        exit;
    }

    /**
     * Class LoginValidaotor
     * This class will enable the spam protection for the login section of wordpress
     */
    class LoginValidator
    {
        public function __construct()
        {
            add_action('login_form', array($this, 'addToLogin'));
            add_filter('wp_authenticate_user', array($this, 'validateSpamProtection'), 10, 2);
        }

        /**
         * Hook into: login_form
         * Used to display the Captcha Input fields on the login page.
         *
         * @return void
         */
        public function addToLogin(){
            /**
             * Generate the Captcha
             */
            $Captcha = new CaptchaMathGenerator();
            $CaptchaItem = $Captcha->getCalculation();

            /**
             * Store the Captcha
             */
            $CaptchaSession = new Captcha();
            $CaptchaSession->setCode($Captcha->get());
            $CaptchaSession->save();

            $fieldname = $this->getPostFieldName();

            /**
             * Print the UI
             */
            ?>
            <label for="f12c"><?php _e('Captcha', 'f12-cf7-captcha');?></label>
            <p><?php echo esc_attr($CaptchaItem);?></p>
            <input id="f12c" type="text" name="<?php echo esc_attr($fieldname);?>" value="" />
            <input type="hidden" id="<?php echo esc_attr($fieldname);?>_hash" name="<?php echo esc_attr($fieldname);?>_hash" value="<?php echo esc_attr($CaptchaSession->getHash());?>"/>
            <?php
        }

        /**
         * Get the Post Field Name from the settings.
         * @return mixed|string
         */
        protected function getPostFieldName()
        {
            $settings = CF7Captcha::getInstance()->getSettings();

            $fieldname = 'f12_captcha';
            if (isset($settings['wp_login_page']['protect_login_fieldname'])) {
                $fieldname = $settings['wp_login_page']['protect_login_fieldname'];
            }
            return $fieldname;
        }

        /**
         * Hook into Hook: wp_authenticate_user
         * Validate the Spam Captcha to ensure that the captcha matches.
         *
         * @param $user
         * @param $password
         * @return mixed|\WP_Error
         */
        public function validateSpamProtection($user, $password)
        {
            $fieldname = $this->getPostFieldName();
            $fieldname_hash = $fieldname.'_hash';

            if(empty($fieldname) || (!isset($_POST[$fieldname]) || empty($_POST[$fieldname]))){
                return new \WP_Error( '500', 'Captcha Error. Please try again.' );
            }

            if(strlen($fieldname_hash) <= 5 || (!isset($_POST[$fieldname_hash])) || empty($_POST[$fieldname_hash])){
                return new \WP_Error( '500', 'Captcha Hash Error. Please try again.' );
            }

            /**
             * Check if the value is set
             */
            $value = sanitize_text_field($_POST[$fieldname]);
            $hash = sanitize_text_field($_POST[$fieldname_hash]);

            if(empty($value)){
                return new \WP_Error( '500', 'Captcha Hash Error. Please try again.' );
            }

            /**
             * Check the Hash Value
             */
            $Captcha = Captcha::getByHash($hash);

            if(!$Captcha){
                return new \WP_Error( '500', 'Captcha Hash not valid. Please try again.' );
            }

            if($Captcha->getCode() != $value){
                return new \WP_Error( '500', 'Captcha Code wrong.' );
            }

            return $user;
        }
    }
}