<?php

namespace forge12\contactform7\CF7Captcha {
    if (!defined('ABSPATH')) {
        exit;
    }

    /**
     * Class UIAvada
     */
    class UIAvada extends UIPage
    {
        public function __construct($domain)
        {
            parent::__construct($domain, 'avada', 'Avada Forms');
        }

        /**
         * Hide if the Avada Theme is not installed
         * @return false|void
         */
        public function hideInMenu(){
            if(!function_exists('Avada')){
                return true;
            }
            return parent::hideInMenu();
        }

        /**
         * Save on form submit
         */
        protected function onSave($settings)
        {
            foreach ($settings['avada'] as $key => $value) {
                if (isset($_POST[$key])) {
                    if (is_numeric($value)) {
                        $settings['avada'][$key] = (int)$_POST[$key];
                    } else {
                        $settings['avada'][$key] = sanitize_text_field($_POST[$key]);
                    }
                } else {
                    $settings['avada'][$key] = 0;
                }
            }

            return $settings;
        }

        protected function addContent($settings)
        {

        }

        /**
         * Render the license subpage content
         */
        protected function theContent($slug, $page, $settings)
        {
            $settings = $settings['avada'];

            ?>
            <h2>
                <?php _e('Avada Forms Settings', $this->domain); ?>
            </h2>

            <div class="option">
                <div class="label">
                    <label for="protect_avada"><?php _e('Avada Forms', $this->domain); ?></label>
                </div>
                <div class="input">
                    <!-- SEPARATOR -->
                    <p style="margin-top:0;"><strong><?php _e('Enable Honeypot Protection', $this->domain); ?></strong>
                    </p>
                    <input
                            id="protect_avada"
                            type="checkbox"
                            value="1"
                            name="protect_avada"
                        <?php echo isset($settings['protect_avada']) && $settings['protect_avada'] === 1 ? 'checked="checked"' : ''; ?>
                    />
                    <span>
                        <label for="protect_avada"><?php _e('Enable Spam Protection for Avada Forms', $this->domain); ?></label>
                    </span>

                    <!-- SEPARATOR -->
                    <p><strong><?php _e('Captcha Fieldname', $this->domain); ?></strong></p>
                    <input
                            id="protect_avada_fieldname"
                            type="text"
                            value="<?php echo $settings['protect_avada_fieldname'] ?? 'f12_captcha'; ?>"
                            name="protect_avada_fieldname"
                    />
                    <span>
                        <label for="protect_avada_fieldname"><?php _e('Enter a unique name for the Captcha field. This makes it harder for bots to recognize the honeypot.', $this->domain); ?></label>
                    </span>

                    <!-- SEPARATOR -->
                    <p><strong><?php _e('Enable Time Based Protection', $this->domain); ?></strong></p>
                    <input
                            id="protect_avada_time_enable"
                            type="checkbox"
                            value="1"
                            name="protect_avada_time_enable"
                        <?php echo isset($settings['protect_avada_time_enable']) && $settings['protect_avada_time_enable'] === 1 ? 'checked="checked"' : ''; ?>
                    />
                    <span>
                        <label for="protect_avada_time_enable"><?php _e('Enable to track the time from entering till submitting the form.', $this->domain); ?></label>
                    </span>

                    <!-- SEPARATOR -->
                    <p><strong><?php _e('Time in Milliseconds', $this->domain); ?></strong></p>
                    <input
                            id="protect_avada_time_ms"
                            type="text"
                            value="<?php echo $settings['protect_avada_time_ms'] ?? 500; ?>"
                            name="protect_avada_time_ms"
                    />
                    <span>
                        <label for="protect_cf7_time_ms"><?php _e('Enter the Time in Milliseconds to determine if the user is a bot (e.g. enter 1000 for 1 second).', $this->domain); ?></label>
                    </span>

                    <!-- SEPARATOR -->
                    <p><strong><?php _e('Timer Fieldname', $this->domain); ?></strong></p>
                    <input
                            id="protect_avada_timer_fieldname"
                            type="text"
                            value="<?php echo $settings['protect_avada_timer_fieldname'] ?? 'f12_timer'; ?>"
                            name="protect_avada_timer_fieldname"
                    />
                    <span>
                        <label for="protect_avada_timer_fieldname"><?php _e('Enter a unique name for the Timer field. This makes it harder for bots to recognize the honeypot.', $this->domain); ?></label>
                    </span>
                </div>
            </div>
            <?php
        }

        protected function theSidebar($slug, $page)
        {
            return;
            ?>
            <div class="box">
                <h2>
                    <?php _e('Hint:', $this->domain); ?>
                </h2>
                <p>
                    <?php _e("", $this->domain); ?>
                </p>
            </div>
            <?php
        }

        /**
         * @param array $settings
         * @return array<mixed>
         */
        public function getSettings($settings){
            $settings['avada'] = array(
                'protect_avada' => 0,
                'protect_avada_time_enable' => 0,
                'protect_avada_time_ms' => 500,
                'protect_avada_fieldname' => 'f12_captcha',
                'protect_avada_timer_fieldname' => 'f12_timer'
            );

            return $settings;
        }

    }
}