<?php

namespace forge12\contactform7\CF7Captcha {
    if (!defined('ABSPATH')) {
        exit;
    }

    /**
     * Class UIDashboard
     */
    class UICF7 extends UIPage
    {
        public function __construct($domain)
        {
            parent::__construct($domain, 'cf7', 'Contact Form 7');
        }

        /**
         * Hide if the CF7 Plugin is not installed
         * @return false|void
         */
        public function hideInMenu(){
            if(!function_exists('wpcf7')){
                return true;
            }
            return parent::hideInMenu();
        }

        /**
         * @param $settings
         * @return array{'protect_cf7_time_enable': string, 'protect_cf7_time_ms': int, 'protect_cf7_fieldname': string}
         */
        public function getSettings($settings){
            $settings['cf7'] = array(
                'protect_cf7_time_enable' => 0,
                'protect_cf7_time_ms' => 500,
                'protect_cf7_fieldname' => 'f12hash',
                'protect_cf7_captcha_enable' => 0,
            );

            return $settings;
        }

        /**
         * Save on form submit
         */
        protected function onSave($settings)
        {
            foreach ($settings['cf7'] as $key => $value) {
                if (isset($_POST[$key])) {
                    if (is_numeric($value)) {
                        $settings['cf7'][$key] = (int)$_POST[$key];
                    } else {
                        $settings['cf7'][$key] = sanitize_text_field($_POST[$key]);
                    }
                } else {
                    $settings['cf7'][$key] = 0;
                }
            }
            return $settings;
        }

        /**
         * Render the license subpage content
         */
        protected function theContent($slug, $page, $settings)
        {
            $settings = $settings['cf7'];

            ?>
            <h2>
                <?php _e('Contact Form 7 Settings', $this->domain); ?>
            </h2>

            <div class="option">
                <div class="label">
                    <label for="protect_comments"><?php _e('Contact Form 7', $this->domain); ?></label>
                </div>
                <div class="input">
                    <!-- SEPARATOR -->
                    <p style="margin-top:0;"><strong><?php _e('Enable Protection', $this->domain); ?></strong></p>
                    <input
                            id="protect_cf7_captcha_enable"
                            type="checkbox"
                            value="1"
                            name="protect_cf7_captcha_enable"
                        <?php echo isset($settings['protect_cf7_captcha_enable']) && $settings['protect_cf7_captcha_enable'] === 1 ? 'checked="checked"' : ''; ?>
                    />
                    <span>
                        <?php _e('Enable the Captcha for every Contact Form 7 available on this system.', $this->domain);?>
                    </span>
                    <p>
                        (<?php _e('You can also enable the protection for each formular individually within the form settings.', $this->domain); ?>)
                    </p>


                    <!-- SEPARATOR -->
                    <p><strong><?php _e('Enable Time Based Protection', $this->domain); ?></strong></p>
                    <input
                            id="protect_cf7_time_enable"
                            type="checkbox"
                            value="1"
                            name="protect_cf7_time_enable"
                        <?php echo isset($settings['protect_cf7_time_enable']) && $settings['protect_cf7_time_enable'] === 1 ? 'checked="checked"' : ''; ?>
                    />
                    <span>
                        <label for="protect_cf7_time_enable"><?php _e('Enable to track the time from entering till submitting the form.', $this->domain); ?></label>
                    </span>

                    <!-- SEPARATOR -->
                    <p><strong><?php _e('Time in Milliseconds', $this->domain); ?></strong></p>
                    <input
                            id="protect_cf7_time_ms"
                            type="text"
                            value="<?php echo $settings['protect_cf7_time_ms'] ?? 500; ?>"
                            name="protect_cf7_time_ms"
                    />
                    <span>
                        <label for="protect_cf7_time_ms"><?php _e('Enter the Time in Milliseconds to determine if the user is a bot (e.g. enter 1000 for 1 second).', $this->domain); ?></label>
                    </span>
                </div>
            </div>
            <?php
        }

        protected function theSidebar($slug, $page)
        {
            return;
            ?>
            <div class="box">
                <h2>
                    <?php _e('Hint:', $this->domain); ?>
                </h2>
                <p>
                    <?php _e("", $this->domain); ?>
                </p>
            </div>
            <?php
        }
    }
}