<?php

namespace forge12\contactform7\CF7Captcha {
    if (!defined('ABSPATH')) {
        exit;
    }

    /**
     * Class UIFilterRules
     */
    class UIFilterRules extends UIPage
    {
        public function __construct($domain)
        {
            parent::__construct($domain, 'filterrules', 'Filter Rules');
        }


        protected function onSave($settings)
        {
            foreach ($settings['rules'] as $key => $value) {
                if (isset($_POST[$key])) {
                    if (is_numeric($value)) {
                        $settings['rules'][$key] = (int)$_POST[$key];
                    } elseif ($key == 'rule_blacklist_value') {
                        update_option('disallowed_keys', sanitize_textarea_field($_POST[$key]));
                    } else {
                        $settings['rules'][$key] = sanitize_text_field($_POST[$key]);
                    }
                } else {
                    $settings['rules'][$key] = 0;
                }
            }
            return $settings;
        }

        /**
         * Render the license subpage content
         */
        protected function theContent($slug, $page, $settings)
        {
            $settings = $settings['rules'];
            $settings['rule_blacklist_value'] = get_option('disallowed_keys');
            ?>
            <h2>
                <?php _e('Filter Rules', $this->domain); ?>
            </h2>

            <div class="option">
                <div class="label">
                    <label for="rule_url"><?php _e('URL', $this->domain); ?></label>
                </div>
                <div class="input">
                    <!-- SEPARATOR -->
                    <p style="margin-top:0;"><strong><?php _e('Enable URL Filter', $this->domain); ?></strong></p>
                    <input
                            id="rule_url"
                            type="checkbox"
                            value="1"
                            name="rule_url"
                        <?php echo isset($settings['rule_url']) && $settings['rule_url'] === 1 ? 'checked="checked"' : ''; ?>
                    />
                    <span>
                        <?php _e('If enabled, all fields will be checked if there are any urls exceeding the followed limit.', $this->domain); ?>
                    </span>

                    <!-- SEPARATOR -->
                    <p><strong><?php _e('URL Limiter', $this->domain); ?></strong></p>
                    <input
                            id="rule_url_limit"
                            type="number"
                            value="<?php echo $settings['rule_url_limit'] ?? 0; ?>"
                            name="rule_url_limit"
                    />
                    <span><?php _e('Define how many links are allowed by one field.', $this->domain); ?></span>

                    <!-- SEPARATOR -->
                    <p><strong><?php _e('Error Message', $this->domain); ?></strong></p>
                    <input
                            id="rule_error_message_url"
                            type="text"
                            value="<?php echo $settings['rule_error_message_url'] ?? __('The Limit %d has been reached. Remove the %s to continue.', 'f12-captcha'); ?>"
                            name="rule_error_message_url"
                    />
                    <p><?php _e('Define the error message displayed to the visitor.', $this->domain); ?></p>
                </div>
            </div>

            <div class="option">
                <div class="label">
                    <label for="rule_bbcode_url"><?php _e('BB Code', $this->domain); ?></label>
                </div>
                <div class="input">
                    <!-- SEPARATOR -->
                    <p style="margin-top:0;"><strong><?php _e('Enable BBCode Filter', $this->domain); ?></strong></p>
                    <input
                            id="rule_bbcode_url"
                            type="checkbox"
                            value="1"
                            name="rule_bbcode_url"
                        <?php echo isset($settings['rule_bbcode_url']) && $settings['rule_bbcode_url'] === 1 ? 'checked="checked"' : ''; ?>
                    />
                    <span>
                        <?php _e('Filter [url={url}]{text}[/url]', $this->domain); ?>
                    </span>

                    <!-- SEPARATOR -->
                    <p><strong><?php _e('Error Message', $this->domain); ?></strong></p>
                    <input
                            id="rule_error_message_bbcode"
                            type="text"
                            value="<?php echo $settings['rule_error_message_bbcode'] ?? __('The Limit %d has been reached. Remove the %s to continue.', 'f12-captcha'); ?>"
                            name="rule_error_message_bbcode"
                    />
                    <p><?php _e('Define the error message displayed to the visitor.', $this->domain); ?></p>
                </div>
            </div>

            <div class="option">
                <div class="label">
                    <label for="rule_blacklist"><?php _e('Blacklist', $this->domain); ?></label>
                </div>
                <div class="input">
                    <!-- SEPARATOR -->
                    <p style="margin-top:0;"><strong><?php _e('Enable Blacklist Filter', $this->domain); ?></strong></p>
                    <input
                            id="rule_blacklist"
                            type="checkbox"
                            value="1"
                            name="rule_blacklist"
                        <?php echo isset($settings['rule_blacklist']) && $settings['rule_blacklist'] === 1 ? 'checked="checked"' : ''; ?>
                    />
                    <span>
                        <?php _e('Enable the blacklist.', $this->domain); ?>
                    </span>

                    <!-- SEPARATOR -->
                    <p><strong><?php _e('Greedy Filter', $this->domain); ?></strong></p>
                    <input
                            id="rule_blacklist_greedy"
                            type="checkbox"
                            value="1"
                            name="rule_blacklist_greedy"
                        <?php echo isset($settings['rule_blacklist_greedy']) && $settings['rule_blacklist_greedy'] === 1 ? 'checked="checked"' : ''; ?>
                    />
                    <span>
                        <?php _e('Enable greedy filter.', $this->domain); ?>
                    </span>


                    <!-- SEPARATOR -->
                    <p><strong><?php _e('Blacklist', $this->domain); ?></strong></p>
                    <textarea
                            rows="20"
                            id="rule_blacklist_value"
                            name="rule_blacklist_value"
                    ><?php echo $settings['rule_blacklist_value'] ?? ''; ?></textarea>
                    <span><?php _e('Define words that should be blacklisted.', $this->domain); ?></span>
                    <br><br>
                    <input type="button" class="button" id="syncblacklist"
                           value="<?php _e('Load Blacklist', $this->domain); ?>"/>

                    <!-- SEPARATOR -->
                    <p><strong><?php _e('Error Message', $this->domain); ?></strong></p>
                    <input
                            id="rule_error_message_blacklist"
                            type="text"
                            value="<?php echo $settings['rule_error_message_blacklist'] ?? __('The word %s is blacklisted.', 'f12-captcha'); ?>"
                            name="rule_error_message_blacklist"
                    />
                    <p><?php _e('Define the error message displayed to the visitor.', $this->domain); ?></p>
                </div>
            </div>

            <div class="option">
                <div class="label">
                    <label for="support"><?php _e('Support Forge12 Captcha: ', $this->domain); ?></label>
                </div>
                <div class="input">
                    <input type="hidden" class="toggle" name="support"
                           value="<?php esc_attr_e($settings['support']); ?>"
                           data-before="<?php _e('On', $this->domain); ?>"
                           data-after="<?php _e('Off', $this->domain); ?>"/>

                    <p>
                        <?php _e('The Footer will contain a noscript referral to support Forge12 Captcha.', $this->domain); ?>
                    </p>
                </div>
            </div>
            <?php
        }

        /**
         * @param $slug
         * @param $page
         *
         * @return void
         */
        protected function theSidebar($slug, $page)
        {
            return;
            ?>
            <div class="box">
                <h2>
                    <?php _e('Hint:', $this->domain); ?>
                </h2>
                <p>
                    <?php _e("", $this->domain); ?>
                </p>
            </div>
            <?php
        }

        /**
         * @param $settings
         *
         * @return mixed
         */
        public function getSettings($settings)
        {
            $settings['rules'] = array(
                'support' => 1,
                'rule_url' => 0,
                'rule_url_limit' => 0,
                'rule_blacklist' => 0,
                'rule_blacklist_greedy' => 1,
                'rule_blacklist_value' => '',
                'rule_bbcode_url' => 0,
                'rule_error_message_url' => __('The Limit %d has been reached. Remove the %s to continue.', 'f12-captcha'),
                'rule_error_message_bbcode' => __('BBCode is not allowed.', 'f12-captcha'),
                'rule_error_message_blacklist' => __('The word %s is blacklisted.', 'f12-captcha'),
            );

            return $settings;
        }

    }
}