<?php

namespace forge12\contactform7\CF7Captcha {
    if (!defined('ABSPATH')) {
        exit;
    }

    /**
     * Class UILogin
     */
    class UILogin extends UIPage
    {
        public function __construct($domain)
        {
            parent::__construct($domain, 'login', 'WordPress Login');
        }

        /**
         * Return the Default settings for the
         * Wordpress Login page.
         *
         * @param $settings
         * @return mixed
         */
        public function getSettings($settings)
        {
            $settings['wp_login_page'] = array(
                'protect_login' => 0,
                'protect_login_fieldname' => 'f12_captcha'
            );

            return $settings;
        }

        /**
         * Save on form submit
         */
        protected function onSave($settings)
        {

            foreach ($settings['wp_login_page'] as $key => $value) {
                if (isset($_POST[$key])) {
                    if (is_numeric($value)) {
                        $settings['wp_login_page'][$key] = (int)$_POST[$key];
                    } else {
                        $settings['wp_login_page'][$key] = sanitize_text_field($_POST[$key]);
                    }
                } else {
                    $settings['wp_login_page'][$key] = 0;
                }
            }

            return $settings;
        }

        protected function theContent($slug, $page, $settings)
        {
            $settings = $settings['wp_login_page'];
            ?>
            <h2>
                <?php _e('WordPress Login Settings', $this->domain); ?>
            </h2>

            <div class="option">
                <div class="label">
                    <label for="protect_login"><?php _e('WordPress Login', $this->domain); ?></label>
                </div>
                <div class="input">
                    <!-- SEPARATOR -->
                    <p style="margin-top:0;"><strong><?php _e('Enable Captcha Protection', $this->domain); ?></strong>
                    </p>
                    <input
                            id="protect_login"
                            type="checkbox"
                            value="1"
                            name="protect_login"
                        <?php echo isset($settings['protect_login']) && $settings['protect_login'] === 1 ? 'checked="checked"' : ''; ?>
                    />
                    <span>
                        <label for="protect_login"><?php _e('Enable Spam Protection for WordPress Login', $this->domain); ?></label>
                    </span>

                    <!-- SEPARATOR -->
                    <p><strong><?php _e('Captcha Fieldname', $this->domain); ?></strong></p>
                    <input
                            id="protect_login_fieldname"
                            type="text"
                            value="<?php echo $settings['protect_login_fieldname'] ?? 'f12_captcha'; ?>"
                            name="protect_login_fieldname"
                    />
                    <span>
                        <label for="protect_login_fieldname"><?php _e('Enter a unique name for the Captcha field. This makes it harder for bots to recognize the honeypot.', $this->domain); ?></label>
                    </span>

                </div>
            </div>
            <?php
        }

        protected function theSidebar($slug, $page)
        {
            if ($page != 'settings') {
                return;
            }
            ?>
            <div class="box">
                <h2>
                    <?php _e('Hint:', $this->domain); ?>
                </h2>
                <p>
                    <?php _e("", $this->domain); ?>
                </p>
            </div>
            <?php
        }
    }
}